@@ -8,7 +8,7 @@ use Object::Pad 0.800;
 
 role App::perl::distrolint::CheckRole::TreeSitterPerl 0.01;
 
-use Syntax::Keyword::Match;
+use Syntax::Keyword::Match 0.13; # case if
 
 use File::Slurper qw( read_text );
 use Text::Treesitter;
